from data_pipeline_helper import build_select_query, build_insert_query

def test_build_select_query():
    query = build_select_query("my_table", ["col1", "col2"], "col1 > 10")
    assert query == "SELECT col1, col2 FROM my_table WHERE col1 > 10"

def test_build_insert_query():
    query = build_insert_query("my_table", ["col1", "col2"], [1, 2])
    assert query == "INSERT INTO my_table (col1, col2) VALUES (1, 2)"


import pandas as pd
from data_pipeline_helper import remove_duplicates,remove_null_values

def test_remove_null_values():
    data = {'col1':[1,None,3],'col2':[4,5,None]}
    df = pd.DataFrame(data)
    result = remove_null_values(df, columns=['col1'])
    assert len(result) == 2

def test_remove_duplicates():
    data = {'col1': [1, 2, 2], 'col2': [3, 4, 4]}
    df = pd.DataFrame(data)
    result = remove_duplicates(df)
    assert len(result) == 2


import pandas as pd

def load_csv_to_dataframe(file_path):
    #load csv
    return pd.read_csv(file_path)

def save_dataframe_to_csv(df, file_path, index = False):
    #saves a dataframe to csv
    df.to_csv(file_path,index = index)


def build_select_query(table, columns, where_clause=None):
    """Generates a SELECT SQL query"""
    query= f"SELECT {', '.join(columns)} FROM {table}"
    if where_clause:
        query += f" WHERE {where_clause}"
    return query

def build_insert_query(table, columns, values):
    """Generates a INSERT SQL query"""
    columns_str = f"({', '.join(columns)})"
    values_str = f"({', '.join(map(str, values))})"
    query = f"INSERT INTO {table} {columns_str} VALUES {values_str}"
    return query


import pandas as pd
import os
from data_pipeline_helper import save_dataframe_to_csv,load_csv_to_dataframe


def test_load_and_save_csv():
    data = {'col1': [1, 2, 3], 'col2': [ 4, 5, 6]}
    df=pd.DataFrame(data)
    temp_file = "temp_test.csv"
    save_dataframe_to_csv(df, temp_file)
    loaded_df = load_csv_to_dataframe(temp_file)
    assert df.equals(loaded_df)
    os.remove(temp_file)